Project
-------------------
vipy: Visym Python Tools for Computer Vision and Machine Learning  
Author: Jeffrey Byrne <jeff@visym.com>  
URL: https://github.com/visym/vipy/  


Requirements
-------------------
python 3.*


Installation
-------------------
```python
pip install numpy scipy scikit-learn matplotlib dill pillow==5.4.1
pip install dropbox flickrapi opencv-python ipython h5py (optional)
```


